This game engine is compartmentalized. There is almost total freedom for making games with this engine. 
Components like collision detection, rendering, etc. can be used as is, replaced, or modified. There is 
physics, a simple GUI structure, math representation for calculus, vectors, and more. The full documentation is on this 
website:

https://micah-ribbens.github.io/Game-Qu/